@@ -1,21 +1,25 @@
 """KGCL parser."""
 import logging
+import re
 import sys
 from pathlib import Path
 from typing import List
 
 import click
+from bioregistry import parse_iri, get_preferred_prefix, curie_to_str
+from kgcl_schema.datamodel.kgcl import (Change, ClassCreation, EdgeCreation,
+                                        EdgeDeletion, NewSynonym,
+                                        NodeAnnotationChange, NodeCreation,
+                                        NodeDeepening, NodeDeletion, NodeMove,
+                                        NodeObsoletion, NodeRename,
+                                        NodeShallowing, NodeUnobsoletion,
+                                        PlaceUnder, PredicateChange,
+                                        RemovedNodeFromSubset, RemoveUnder,
+                                        Session)
+from kgcl_schema.datamodel.ontology_model import Edge
 from kgcl_schema.utils import to_json, to_rdf, to_yaml
 from lark import Lark, Token
 
-from kgcl_schema.datamodel.kgcl import (ClassCreation, EdgeCreation, EdgeDeletion,
-                                        NewSynonym, NodeAnnotationChange, NodeCreation,
-                                        NodeDeepening, NodeDeletion, NodeMove,
-                                        NodeObsoletion, NodeRename, NodeShallowing,
-                                        NodeUnobsoletion, PlaceUnder, PredicateChange,
-                                        RemovedNodeFromSubset, RemoveUnder, Change, Session)
-from kgcl_schema.datamodel.ontology_model import Edge
-
 
 def id_generator():
     """Return a new ID for KGCL change operations."""
@@ -54,6 +58,16 @@ def parse_statement(input: str) -> Change:
 
     Return an instantiated dataclass object from model.kgcl_schema.
     """
+    # regex = r'http[s]?://(?:[a-zA-Z]|[0-9]|[$-_@.&+]|[!*\(\),]|(?:%[0-9a-fA-F][0-9a-fA-F]))+'
+    # uri_list = re.findall(regex, input)
+    # if uri_list:
+    #     # curie = curie_from_iri(uri[0].replace("<", "").replace(">",""))
+    #     for _, uri in enumerate(uri_list):
+    #         pref, i = parse_iri(uri)
+    #         pref = get_preferred_prefix(pref)
+    #         curie = curie_to_str(pref, i)
+    #         input = input.replace(uri, curie)
+
     tree = kgcl_parser.parse(input)
     id = "kgcl_change_id_" + str(next(id_gen))
 
@@ -167,12 +181,12 @@ def parse_create(tree, id):
     language_token = extract(tree, "language")
 
     entity, representation = get_entity_representation(term_id_token)
-
+    
     return NodeCreation(
         id=id,
         about_node=entity,
         about_node_representation=representation,
-        node_id=term_id_token,
+        node_id=entity, # was term_id_token
         name=label_token,
         language=language_token,
     )
@@ -503,7 +517,7 @@ def get_entity_representation(entity):
     first_character = entity[0]
     last_character = entity[-1:]
     if first_character == "<" and last_character == ">":
-        return entity, "uri"  # not removing brackets (TODO why?)
+        return contract_uri(entity.replace("<", "").replace(">","")), "curie"  # removing brackets
     if first_character == "'" and last_character == "'" and entity[1] != "'":
         return entity[1:-1], "label"
     if first_character == '"' and last_character == '"':
@@ -514,9 +528,17 @@ def get_entity_representation(entity):
         return entity[3:-3], "literal"
 
     # TODO: use predefined set of prefixes to identify CURIEs
-    return entity, "curie"
+    return contract_uri(str(entity)), "curie"
     # return entity, "error"
 
+def contract_uri(uri_or_curie:str):
+    if uri_or_curie.startswith("http://") or uri_or_curie.startswith("https://"):
+        pref, i = parse_iri(uri_or_curie)
+        pref = get_preferred_prefix(pref)
+        curie = curie_to_str(pref, i)
+        return curie
+    else:
+        return uri_or_curie
 
 @click.command()
 @click.option("--output",
